@@ -20,13 +20,17 @@
       \endverbatim
   */
 
-struct MiConvOpts : JcampDxBlock {
+struct MiConvOpts : LDRblock {
 
-  JDXstring protfile;
-  JDXstring parlist;
+  LDRbool   quiet;
+  LDRstring protfile;
+  LDRstring parlist;
 
   MiConvOpts() {
 
+    quiet.set_cmdline_option("q").set_description("Quiet mode: do not print progress meter");
+    append_member(quiet,"quiet");
+
     protfile.set_cmdline_option("p").set_description("Load this protcol for defaults");
     append_member(protfile,"protfile");
 
@@ -104,7 +108,7 @@ int main(int argc, char* argv[]) {
   if(mopts.parlist=="help") {
     STD_cout << "Possible protocol parameters:" << STD_endl;
     for(unsigned int i=0; i<prot_template.numof_pars(); i++) {
-      JcampDxClass& ldr=prot_template[i];
+      LDRbase& ldr=prot_template[i];
       if(ldr.get_filemode()!=exclude) {
 	STD_cout <<  ldr.get_label() << STD_endl;
       }
@@ -115,7 +119,7 @@ int main(int argc, char* argv[]) {
   svector pars;
   if(mopts.parlist=="all") {
     for(unsigned int i=0; i<prot_template.numof_pars(); i++) {
-      JcampDxClass& ldr=prot_template[i];
+      LDRbase& ldr=prot_template[i];
       if(ldr.get_filemode()!=exclude) pars.push_back(ldr.get_label());
     }
   } else {
@@ -140,7 +144,10 @@ int main(int argc, char* argv[]) {
 
   ProgressDisplayConsole display;
   ProgressMeter progmeter(display);
-  int readresult=FileIO::autoread(pdmap_in, infile, ropts, prot_template,&progmeter);
+  ProgressMeter* progmeter_ptr=0;
+  if(!mopts.quiet) progmeter_ptr=&progmeter;
+
+  int readresult=FileIO::autoread(pdmap_in, infile, ropts, prot_template,progmeter_ptr);
 
   if(readresult<0) {
     ODINLOG(odinlog,errorLog) << "autoread failed" << STD_endl;
