@@ -4,25 +4,25 @@
 
 #include "odindialog_process.h"
 
-#include <odinqt/jdxblockwidget.h>
+#include <odinqt/ldrblockwidget.h>
 
 #include <odinseq/seqmakefile.h>
 
 ////////////////////////////////////////////////////////////////////////////////////////
 // Helper functions
 
-bool select_alternative(JDXfileName& result, const STD_list<STD_string>& alternatives, QWidget *parent=0) {
+bool select_alternative(LDRfileName& result, const STD_list<STD_string>& alternatives, QWidget *parent=0) {
   Log<OdinComp> odinlog("","select_alternative");
 
   if(parent && alternatives.size()>1) { // Ask with dialog if parent is provided
 
-    JDXenum alts;
+    LDRenum alts;
     alts.set_label("Alternatives");
     for(STD_list<STD_string>::const_iterator it=alternatives.begin(); it!=alternatives.end(); ++it) alts.add_item(*it);
 
-    JcampDxBlock block("Select Alternative");
+    LDRblock block("Select Alternative");
     block.append(alts);
-    new JDXwidgetDialog(block,1,parent,true);
+    new LDRwidgetDialog(block,1,parent,true);
 
     result=alts.operator STD_string();
 
@@ -41,7 +41,7 @@ bool select_alternative(JDXfileName& result, const STD_list<STD_string>& alterna
 }
 
 void select_idea_include_dirs(STD_string& result, const STD_list<STD_string>& possible_dirs, const IdeaOpts& opts) {
-  JDXfileName testdir;
+  LDRfileName testdir;
   testdir.set_dir(true);
   STD_string ideadir_slash=opts.get_ideadir_slash();
   for(STD_list<STD_string>::const_iterator it=possible_dirs.begin(); it!=possible_dirs.end(); ++it) {
@@ -57,7 +57,7 @@ svector match_in_dir(const STD_string& dir, const STD_string& match) {
   svector dirs=browse_dir(dir, true,true);
   for(unsigned int i=0; i<dirs.size(); i++) {
     if(tolowerstr(dirs[i]).find(match)==0) {
-      result.push_back(JDXfileName(dir+"/"+dirs[i])); // better formatting
+      result.push_back(LDRfileName(dir+"/"+dirs[i])); // better formatting
     }
   }
   return result;
@@ -72,7 +72,7 @@ STD_string mgwpath(const STD_string& path) {
 
 ////////////////////////////////////////////////////////////////////////////////////////
 
-IdeaOpts::IdeaOpts() : JcampDxBlock("ODIN for IDEA settings") {
+IdeaOpts::IdeaOpts() : LDRblock("ODIN for IDEA settings") {
 
   arch.set_description("ODIN source code archive to be compiled");
   append_member(arch,"ODIN source code");
@@ -119,8 +119,11 @@ IdeaOpts::IdeaOpts() : JcampDxBlock("ODIN for IDEA settings") {
   make_clean.set_description("Clean up build directory before and after build process");
   append_member(make_clean,"Make clean");
 
-
+#ifdef ODIN_DEBUG
+  parameterMode parmode=noedit;
+#else
   parameterMode parmode=hidden;
+#endif
 
   vxworks_dir.set_dir(true);
   vxworks_dir.set_parmode(parmode).set_description("VxWorks compiler/linker directory");
@@ -149,16 +152,19 @@ IdeaOpts::IdeaOpts() : JcampDxBlock("ODIN for IDEA settings") {
 
 
 
-void IdeaOpts::set_defaults(const OdinConf& conf, QWidget *parent) {
+bool IdeaOpts::set_defaults(const OdinConf& conf, STD_string* errmsg, QWidget *parent) {
   Log<OdinComp> odinlog("IdeaOpts","set_defaults");
 
   STD_list<STD_string> possible_arch;
   possible_arch.push_back(conf.get_installdir()+SEPARATOR_STR+"src"+SEPARATOR_STR+PACKAGE+"-"+VERSION+".tar.gz");
-  select_alternative(arch,possible_arch);
+  if(!select_alternative(arch,possible_arch)) {
+    if(errmsg) (*errmsg)="Cannot find Odin source archive";
+    return false;
+  }
 
   STD_list<STD_string> possible_ideadirs;
 
-  JDXfileName midearoot("C:/MIDEA");
+  LDRfileName midearoot("C:/MIDEA");
   midearoot.set_dir(true);
   if(midearoot.exists()) { // VB*
     svector mideadirs=match_in_dir("C:/MIDEA", "n4_");
@@ -167,16 +173,30 @@ void IdeaOpts::set_defaults(const OdinConf& conf, QWidget *parent) {
      possible_ideadirs.push_back("V:");
   }
 
-  select_alternative(ideadir,possible_ideadirs,parent);
+  if(!select_alternative(ideadir,possible_ideadirs,parent)){ // Ask with dialog in case of multiple IDEAs
+    if(errmsg) (*errmsg)="Cannot find IDEA directory";
+    return false;
+  }
 
   odindir=conf.get_installdir()+SEPARATOR_STR+"Odin4Idea";
 
-  msvcdir="C:/MSVStudio6";
+  LDRfileName msdevdir(getenv_nonnull("MsDevDir"));
+  if(msdevdir=="") {
+    if(errmsg) (*errmsg)="Cannot find Visual Studio environment variable MsDevDir";
+    return false;
+  }
+  msvcdir=LDRfileName(msdevdir.get_dirname()).get_dirname(); // two levels up
+//  msvcdir="C:/MSVStudio6";
+  ODINLOG(odinlog,normalDebug) << "msdevdir - msvcdir=" << msdevdir << " - " << msvcdir << STD_endl;
 
   STD_list<STD_string> possible_seqdirs;
   possible_seqdirs.push_back(ideadir+SEPARATOR_STR+"n4/pkg/MrServers/MrImaging/seq");
   possible_seqdirs.push_back(ideadir+SEPARATOR_STR+"n4/comp/Application/seq");
-  select_alternative(seqdir,possible_seqdirs);
+  if(!select_alternative(seqdir,possible_seqdirs)) {
+    if(errmsg) (*errmsg)="Cannot find sequence directory";
+    return false;
+  }
+
 
   odin2idea_label="odin";
 
@@ -184,19 +204,42 @@ void IdeaOpts::set_defaults(const OdinConf& conf, QWidget *parent) {
   possible_icedirs.push_back(ideadir+SEPARATOR_STR+"n4/pkg/MrServers/MrIcePrograms"); // pre VB15
   possible_icedirs.push_back(ideadir+SEPARATOR_STR+"n4/pkg/MrServers/MrVista/Ice/IceIdeaFunctors"); // VB15
   possible_icedirs.push_back(seqdir); // fallback
-  select_alternative(icedir,possible_icedirs);
+  if(!select_alternative(icedir,possible_icedirs)) {
+    if(errmsg) (*errmsg)="Cannot find ICE directory";
+    return false;
+  }
 
   vxworks_heap_size=3;
 
   debug_vxworks_host=false;
 
-  JDXfileName ccpentium(ideadir+"/n4_fsp/tornado/i86/host/x86-win32/bin/ccpentium.exe");
+
+  STD_list<STD_string> vxworks_dir_alternatives;
+  vxworks_dir_alternatives.push_back(ideadir+"/n4_fsp/tornado/i86/host/x86-win32");
+  vxworks_dir_alternatives.push_back(ideadir+"/n4_fsp/tornado/ppc/host/x86-win32");
+  vxworks_dir_alternatives.push_back(ideadir+"/n4_fsp/WindRiver/gnu/4.3.3-vxworks-6.9/x86-win32");
+  if(!select_alternative(vxworks_dir, vxworks_dir_alternatives)) {
+    if(errmsg) (*errmsg)="Cannot find vxworks directory";
+    return false;
+  }
+
+  STD_list<STD_string> vxworks_path_alternatives;
+  vxworks_path_alternatives.push_back(vxworks_dir+"/lib/gcc-lib/powerpc-wrs-vxworks/cygnus-2.7.2-960126");
+  vxworks_path_alternatives.push_back(vxworks_dir+"/bin"); // for VB12
+  if(!select_alternative(vxworks_path, vxworks_path_alternatives)) {
+    if(errmsg) (*errmsg)="Cannot find vxworks executable path";
+    return false;
+  }
+
+
+  LDRfileName ccpentium(vxworks_path+SEPARATOR_STR+"ccpentium.exe");
   if(ccpentium.exists()) vxworks_cpu.set_actual("PENTIUM");
   else vxworks_cpu.set_actual("PPC750");
 
   make_jobs=numof_cores();
   make_clean=true;
 
+  return true;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -236,7 +279,7 @@ IdeaDialog::IdeaDialog(QWidget *parent, IdeaOpts& opts, const OdinConf& conf)
 
   grid=new GuiGridLayout(GuiDialog::get_widget(), 2, 3);
 
-  optswidget=new JDXwidget(opts,2,GuiDialog::get_widget());
+  optswidget=new LDRwidget(opts,2,GuiDialog::get_widget());
   connect(optswidget,SIGNAL(valueChanged()),this,SLOT(update()));
   grid->add_widget( optswidget, 0, 0, GuiGridLayout::Default, 1, 3 );
 
@@ -258,7 +301,10 @@ void IdeaDialog::cancel() {
 }
 
 void IdeaDialog::defaults() {
-  opts_cache.set_defaults(conf_cache, GuiDialog::get_widget());
+  STD_string errmsg;
+  if(!opts_cache.set_defaults(conf_cache, &errmsg, GuiDialog::get_widget())) {
+    error_msg(errmsg);
+  }
   update(); // update other parameters
   optswidget->updateWidget();
   emit changed();
@@ -275,7 +321,7 @@ void IdeaDialog::error_msg(const STD_string& msg) {
 }
 
 int IdeaDialog::find_in_alternatives(const STD_string& findstr, const STD_list<STD_string>& alternatives) {
-  JDXfileName fname;
+  LDRfileName fname;
   if(!select_alternative(fname, alternatives)) {
     error_msg("Cannot find file containing "+findstr);
     return -1;
@@ -325,7 +371,8 @@ STD_string IdeaDialog::hosttarget(bool debug, const STD_string& build_includes,
   result+="build-"+target+":\n";
   result+=mprefix+"cd "+target+"/build && "+make_install+"\n";
   // add lib prefix, if missing
-  result+=mprefix+"for odinlibname in tjutils odinpara odinseq ; do if test -f "+target+"/lib/$${odinlibname}.lib ; then mv "+target+"/lib/$${odinlibname}.lib "+target+"/lib/lib$${odinlibname}.lib ; fi; done\n\n";
+  // and add lib version with postfix 'd' (quick hack for VB20)
+  result+=mprefix+"for odinlibname in tjutils odinpara odinseq ; do if test -f "+target+"/lib/$${odinlibname}.lib ; then mv "+target+"/lib/$${odinlibname}.lib "+target+"/lib/lib$${odinlibname}.lib ; fi; cp "+target+"/lib/lib$${odinlibname}.lib "+target+"/lib/lib$${odinlibname}d.lib; done\n\n";
 
   result+="build-"+target+"-clean: build-"+target+"\n";
   result+=mprefix+"rm -rf "+target+"/build\n\n";
@@ -374,8 +421,13 @@ STD_string IdeaDialog::errcodes_src(const STD_string& msgfile) {
 void IdeaDialog::do_compile() {
   Log<OdinComp> odinlog("IdeaDialog","do_compile");
 
-  JDXfileName msys_bin(conf_cache.get_installdir()+SEPARATOR_STR+"msys"+SEPARATOR_STR+"bin");
-  JDXfileName make(msys_bin+"/make.exe");
+  // for testing existence of files/dirs
+  LDRfileName testfile;
+  LDRfileName testdir; testdir.set_dir(true);
+
+
+  LDRfileName msys_bin(conf_cache.get_installdir()+SEPARATOR_STR+"msys"+SEPARATOR_STR+"bin");
+  LDRfileName make(msys_bin+"/make.exe");
   if(!make.exists()) {
     error_msg("Cannot find make program "+make);
     return;
@@ -396,7 +448,7 @@ void IdeaDialog::do_compile() {
 
 
   // Parse IDEA error codes
-  JDXfileName msgfile;
+  LDRfileName msgfile;
   STD_list<STD_string> msgfile_alternatives;
   msgfile_alternatives.push_back(opts_cache.ideadir+"/n4/x86/delivery/include/Measurement/Sequence/libRT/libRTmsg.h"); // pre VA25
   msgfile_alternatives.push_back(opts_cache.ideadir+"/n4/x86/delivery/include/MrServers/MrMeasSrv/SeqIF/libRT/libRTmsg.h"); // VA25 and later
@@ -426,7 +478,7 @@ void IdeaDialog::do_compile() {
 
   STD_string makefile;
 
-  JDXfileName shell=msys_bin+SEPARATOR_STR+"sh.exe";
+  LDRfileName shell=msys_bin+SEPARATOR_STR+"sh.exe";
   if(!shell.exists()) {
     error_msg("Cannot find shell "+shell);
     return;
@@ -488,9 +540,16 @@ void IdeaDialog::do_compile() {
     it->second=mgwpath(opts_cache.odindir)+"/bin/"+tool+"wrapper.exe";
   }
 
+
+  // for VB20
+  LDRfileName lmapi_dll_dir(opts_cache.ideadir+"/n4_fsp/WindRiver/lmapi-5.0/x86-win32/bin");
+  STD_string lmapi_dll_path;
+  if(lmapi_dll_dir.exists()) lmapi_dll_path=replaceStr(lmapi_dll_dir,"\\","/")+";"; // replace backslashes by slashes
+
+
   // create cxxwrapper.exe
   makefile+=mprefix+"echo \"cxx=\\\""+replaceStr(vxworks_cxx,"\\","/")+"\\\";\" > ${ARCHNAME}/replacements/cxxwrapper_config.h\n";
-  if(opts_cache.vxworks_path!="") makefile+=mprefix+"echo \"cxxpath=\\\""+vxworks_path_slash+"\\\";\" >> ${ARCHNAME}/replacements/cxxwrapper_config.h\n";
+  if(opts_cache.vxworks_path!="") makefile+=mprefix+"echo \"cxxpath="+"\\\""+lmapi_dll_path+vxworks_path_slash+"\\\";\" >> ${ARCHNAME}/replacements/cxxwrapper_config.h\n";
   makefile+=mprefix+gcc+" ${ARCHNAME}/replacements/cxxwrapper.cpp -o bin/cxxwrapper.exe\n";
   tools["cxx"]=mgwpath(opts_cache.odindir)+"/bin/cxxwrapper.exe";
 
@@ -513,7 +572,7 @@ void IdeaDialog::do_compile() {
   confstr+=" CFLAGS=\""+vxworks_cxxflags+"\"";
   confstr+=" CPP=\""+tools["cpp"]+" "+vxworks_cppflags+"\"";
   confstr+=" ../../${ARCHNAME}/configure --host="+mpcu_postfix+"-wrs-vxworks "+global_conf;
-  confstr+=" --enable-custom-heap="+itos(opts_cache.vxworks_heap_size)+" --disable-filehandling";
+  confstr+=" --enable-custom-heap="+itos(opts_cache.vxworks_heap_size)+" --disable-filehandling --disable-processhandling";
   confstr+=" ${DEBUGOPT} --prefix="+odindir_slash+"/vxworks";
 
   makefile+="configure-vxworks:\n";
@@ -548,7 +607,7 @@ void IdeaDialog::do_compile() {
 
 
   // find location of IDEA libs
-  JDXfileName idea_libdir;
+  STD_string idea_libdir;
   svector n4_delis=match_in_dir(opts_cache.ideadir, "n4_deli_");
   if(n4_delis.size()) {
     idea_libdir=n4_delis[0]+"/x86/delivery/lib"; // VA 25
@@ -557,8 +616,6 @@ void IdeaDialog::do_compile() {
   }
 
   bool has_idea_libdir=false;
-  JDXfileName testdir;
-  testdir.set_dir(true);
   testdir=idea_libdir;
   if(testdir.exists()) has_idea_libdir=true;
 
@@ -578,6 +635,7 @@ void IdeaDialog::do_compile() {
 
   // find location of IDEA includes
   STD_list<STD_string> possible_includepaths;
+
   // pre VA25
   possible_includepaths.push_back("n4/comp");
   possible_includepaths.push_back("n4/comp/STLport");
@@ -589,8 +647,21 @@ void IdeaDialog::do_compile() {
   possible_includepaths.push_back("n4/comp/Application/seq");
   possible_includepaths.push_back("n4/comp/ExamUI/ExamDb/Protocol/UILink/StdProtRes");
   possible_includepaths.push_back("n4/comp/Common/STL");
+
   // VA25 and later
   possible_includepaths.push_back("n4/pkg");
+
+/*
+  possible_includepaths.push_back("n4/interfaces/deli/n4/pkg"); // VB20
+  possible_includepaths.push_back("n4/tool"); // VB20
+  possible_includepaths.push_back("n4/interfaces/deli/n4/tool"); // VB20
+  possible_includepaths.push_back("n4/opensource/STLport/stlport"); // VB20
+  possible_includepaths.push_back("n4/x86/prod/include"); // VB20
+  possible_includepaths.push_back("n4/x86/delivery/include"); // VB20
+  possible_includepaths.push_back("n4/x86/extsw/MedCom/include"); // VB20
+  possible_includepaths.push_back("SWF_extern/SDK/include"); // VB20
+*/
+
   possible_includepaths.push_back("n4/pkg/STLport");
   possible_includepaths.push_back("n4_extsw/x86/extsw/MedCom/versant/vds605/h");
   possible_includepaths.push_back("n4/pkg/MrServers/MrMeasSrv/SeqIF");
@@ -601,6 +672,7 @@ void IdeaDialog::do_compile() {
   possible_includepaths.push_back("n4/pkg/MrServers/MrProtSrv/MrProtocol/UILink/StdProtRes");
   possible_includepaths.push_back("n4/pkg/MrCommon/MrCFramework/STL");
 
+
   STD_string idea_includes;
   for(STD_list<STD_string>::const_iterator it=possible_includepaths.begin(); it!=possible_includepaths.end(); ++it) {
     testdir=opts_cache.ideadir+SEPARATOR_STR+(*it);
@@ -621,15 +693,15 @@ void IdeaDialog::do_compile() {
   STD_string idea_defines;
 
   // checking iPAT (parallel imaging) capability
-  JDXfileName testfile(opts_cache.ideadir+"/n4/pkg/MrServers/MrImaging/seq/common/iPAT/iPAT.h");
+  testfile=opts_cache.ideadir+"/n4/pkg/MrServers/MrImaging/seq/common/iPAT/iPAT.h";
   if(testfile.exists()) idea_defines="-DHAVE_iPAT";
 
   // checking whether standard STL header 'vector' is available (which is the case on VB13)
 
   STD_list<STD_string> vector_header_alternatives;
   vector_header_alternatives.push_back(opts_cache.ideadir+"/n4_opensource/STLport/stlport/vector");
-  vector_header_alternatives.push_back(opts_cache.ideadir+"/n4/opensource/STLport/stlport/vector"); // VB18P
-  JDXfileName vector_header_file;
+  vector_header_alternatives.push_back(opts_cache.ideadir+"/n4/opensource/STLport/stlport/vector"); // VB18 and later
+  LDRfileName vector_header_file;
   select_alternative(vector_header_file, vector_header_alternatives);
   if(vector_header_file.exists()) idea_defines+=" -DHAVE_STL_VECTOR";
 
@@ -664,8 +736,8 @@ void IdeaDialog::do_compile() {
 
   // Assume new Linux-based Ice reco is there if IceConfigurators are present
   STD_string icecmd="MakeIcePrg";
-  testfile=opts_cache.ideadir+"/n4/pkg/MrServers/MrVista/Config/IceConfigurators";
-  if(testfile.exists()) {
+  testdir=opts_cache.ideadir+"/n4/pkg/MrServers/MrVista/Config/IceConfigurators";
+  if(testdir.exists()) {
     idea_defines+=" -DHAVE_ICE_CONFIGURATOR";
     icecmd="mi";
   }
@@ -722,7 +794,7 @@ void IdeaDialog::do_compile() {
 
   // copying files
   makefile+=mprefix+"cp ${ARCHNAME}/platforms/IDEA_n4/odin2idea.cpp ${ODIN2IDEADIR_MGWPATH}\n";
-  makefile+=mprefix+"cp ${ARCHNAME}/platforms/IDEA_n4/tjdx4idea.h ${ODIN2IDEADIR_MGWPATH}\n";
+  makefile+=mprefix+"cp ${ARCHNAME}/platforms/IDEA_n4/ldr4idea.h ${ODIN2IDEADIR_MGWPATH}\n";
   makefile+=mprefix+"cat ${ARCHNAME}/platforms/IDEA_n4/makefile.trs | sed s/ODIN2IDEA_TAG/${ODIN2IDEA_LABEL}/ > ${ODIN2IDEADIR_MGWPATH}/makefile.trs\n";
 
 
@@ -850,16 +922,22 @@ void IdeaDialog::update() {
   // set compilers and path of tools
   opts_cache.win_cxx=opts_cache.msvcdir+"/VC98/Bin/cl.exe";
 
+/*
   STD_list<STD_string> vxworks_dir_alternatives;
   vxworks_dir_alternatives.push_back(opts_cache.ideadir+"/n4_fsp/tornado/i86/host/x86-win32");
   vxworks_dir_alternatives.push_back(opts_cache.ideadir+"/n4_fsp/tornado/ppc/host/x86-win32");
-  select_alternative(opts_cache.vxworks_dir, vxworks_dir_alternatives);
+  vxworks_dir_alternatives.push_back(opts_cache.ideadir+"/n4_fsp/WindRiver/gnu/4.3.3-vxworks-6.9/x86-win32");
+  if(!select_alternative(opts_cache.vxworks_dir, vxworks_dir_alternatives)) {
+    error_msg("Cannot find vxworks directory");
+  }
 
   STD_list<STD_string> vxworks_path_alternatives;
   vxworks_path_alternatives.push_back(opts_cache.vxworks_dir+"/lib/gcc-lib/powerpc-wrs-vxworks/cygnus-2.7.2-960126");
   vxworks_path_alternatives.push_back(opts_cache.vxworks_dir+"/bin"); // for VB12
-  select_alternative(opts_cache.vxworks_path, vxworks_path_alternatives);
-
+  if(!select_alternative(opts_cache.vxworks_path, vxworks_path_alternatives)) {
+    error_msg("Cannot find vxworks executable path");
+  }
+*/
 
   STD_string global_includes;
   STD_string global_defines;
@@ -887,11 +965,12 @@ void IdeaDialog::update() {
 
 
   // extra includes for VxWorks
-  JDXfileName vxworks_target_includes;
+  LDRfileName vxworks_target_includes;
   vxworks_target_includes.set_dir(true);
   STD_list<STD_string> vxworks_target_includes_alternatives;
   vxworks_target_includes_alternatives.push_back(opts_cache.ideadir+"/n4/pkg/MrServers/MrMPCUSystem/Tornado_i86/target/h");
   vxworks_target_includes_alternatives.push_back(opts_cache.ideadir+"/n4_fsp/tornado/ppc/target/h");
+  vxworks_target_includes_alternatives.push_back(opts_cache.ideadir+"/n4_fsp/WindRiver/vxworks-6.9/target/h"); // VB20
   select_alternative(vxworks_target_includes, vxworks_target_includes_alternatives);
 
 
@@ -913,7 +992,7 @@ void IdeaDialog::update() {
   if(retval>0) global_defines+=" -DHAVE_MRCOILSELECT_FFTSCALE";
 
 
-  opts_cache.vxworks_flags=global_includes+" -I"+replaceStr(vxworks_target_includes,"\\","/")+" "+global_defines+" -DVXWORKS -DCPU="+opts_cache.vxworks_cpu.JDXenum::operator STD_string();
+  opts_cache.vxworks_flags=global_includes+" -I"+replaceStr(vxworks_target_includes,"\\","/")+" "+global_defines+" -DVXWORKS -DCPU="+opts_cache.vxworks_cpu.LDRenum::operator STD_string();
 
   opts_cache.vxworks_opts="-ansi";
   if(tolowerstr(opts_cache.vxworks_cpu).find("pentium")!=STD_string::npos) {
@@ -926,6 +1005,8 @@ void IdeaDialog::update() {
   STD_list<STD_string> possible_hostall_includepaths;
   possible_hostall_includepaths.push_back("n4/comp/STLport"); // VA* path
   possible_hostall_includepaths.push_back("n4_opensource/STLport/stlport"); // VB* path, if this path is absent, the MSVC iostream would be used which fails
+  possible_hostall_includepaths.push_back("n4/opensource/STLport/stlport"); // VB20
+
   possible_hostall_includepaths.push_back("n4_extsw/x86/extsw/MedCom/include"); // VA* path
   possible_hostall_includepaths.push_back("n4/x86/extsw/MedCom/include"); // VB* path
   STD_string hostall_idea_includes;
@@ -933,7 +1014,8 @@ void IdeaDialog::update() {
 
   STD_string hostall_defines=global_defines+" -DWIN32 -D_AFXDLL -DCSA_HAS_DLL -D_MBCS -DAFX_NOVTABLE= -D_RWTOOLSDLL -D_UNICODE -DUNICODE -DO_DLL_PCLASS_ONLY -D_CONSOLE -D_WINDLL -DACE_HAS_DLL";
   STD_string hostall_includes=global_includes+" "+hostall_idea_includes;
-  STD_string hostall_opts="-nologo -Z7 -O2 -GR -GX -G5 -GF";
+//  STD_string hostall_opts="-nologo -Z7 -O2 -GR -GX -G5 -GF";
+  STD_string hostall_opts="-nologo -Zi -O2 -GR -GX -G5 -GF";
 
   opts_cache.hostd_flags=hostall_defines+" "+hostall_includes+" "+hostall_opts+" -MDd";
   opts_cache.host_flags= hostall_defines+" "+hostall_includes+" "+hostall_opts+" -MD";
