@@ -65,7 +65,7 @@ int FileFormat::write(const FileIO::ProtocolDataMap& pdmap, const STD_string& fi
 
 
 STD_string FileFormat::analyze_suffix(const STD_string& filename) {
-  JDXfileName fname(filename);
+  LDRfileName fname(filename);
   return fname.get_suffix();
 }
 
@@ -202,9 +202,9 @@ svector FileFormat::create_unique_filenames(const STD_string& filename, const Fi
 
 
   // Decompose file name to insert unique name before first known prefix
-  JDXfileName fname(filename);
+  LDRfileName fname(filename);
   svector fmts=FileIO::autoformats();
-  JDXfileName bname=fname.get_basename_nosuffix();
+  LDRfileName bname=fname.get_basename_nosuffix();
   STD_string fnamesuff(fname.get_suffix());
   STD_string suffixstr;
   if(fnamesuff!="") suffixstr="."+fname.get_suffix();
@@ -267,7 +267,8 @@ void register_dicom_format();
 void register_gzip_format();
 void register_hfss_format();
 void register_interfile_format();
-void register_jdx_format();
+void register_ismrmrd_format();
+void register_ser_format();
 void register_mhd_format();
 void register_mat_format();
 void register_nifti_format();
@@ -286,7 +287,8 @@ struct FileFormatCreator : public StaticHandler<FileFormatCreator> {
     register_dicom_format();
     register_gzip_format();
     register_interfile_format();
-    register_jdx_format();
+    register_ismrmrd_format();
+    register_ser_format();
     register_mhd_format();
     register_mat_format();
     register_nifti_format();
@@ -318,7 +320,7 @@ int FileIO::autoread(ProtocolDataMap& pdmap, const STD_string& filename, const F
 
   // override file suffix if jdx option is given
   STD_string suffix=opts.format;
-  if(opts.jdx!="") suffix="smp";
+  if(opts.ldr!="") suffix="smp";
 
   int result=-1;
 
@@ -370,7 +372,7 @@ int FileIO::autoread(ProtocolDataMap& pdmap, const STD_string& filename, const F
     // Set label of protocol to filename
     STD_string postfix;
     if(pdmapin.size()>1) postfix=":"+itos(cnt,pdmapin.size()-1);
-    prot.set_label("Protocol of "+filename+postfix);
+    prot.set_label("Protocol of "+LDRfileName(filename).get_basename()+postfix);
 
 
     const Data<float,4>& data=pdit->second;
@@ -641,7 +643,7 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
     ODINLOG(odinlog,normalDebug) << "min_acqstart: " << min_acqstart << " max_acqstart: " << max_acqstart << " dur: "<< max_acqstart - min_acqstart+ prot.seqpars.get_RepetitionTime()/1000 << STD_endl;
     prot.seqpars.set_ExpDuration( (max_acqstart - min_acqstart+ prot.seqpars.get_RepetitionTime()/1000 ) /60.0);
 
-    int nslices=shape(sliceDim);
+    unsigned int nslices=shape(sliceDim);
 
     // overwrite slice settings in protocol
     prot.geometry.set_nSlices(nslices);
@@ -649,10 +651,10 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
     // store slice order in protocol for following steps
     ODINLOG(odinlog,normalDebug) << "nslices/sliceindexmap.size()=" << nslices << "/" << sliceindexmap.size() << STD_endl;
     if( nslices>1 && nslices<=sliceindexmap.size()) {
-      JDXintArr sliceorder;
+      LDRintArr sliceorder;
       sliceorder.redim(nslices); sliceorder.set_label("SliceOrder"); // separately instead of using constructor for GCC3.2
       STD_map<double,int>::const_iterator it=sliceindexmap.begin();
-      for(int i=0; i<nslices; i++) {
+      for(unsigned int i=0; i<nslices; i++) {
         sliceorder[i]=it->second;
         ++it;
       }
@@ -685,7 +687,6 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
 
 int FileIO::autowrite(const ProtocolDataMap& pdmap, const STD_string& filename, const FileWriteOpts& opts) {
   Log<FileIO> odinlog("FileIO","autowrite");
-  Range all=Range::all();
 
   if(filename=="") {
     ODINLOG(odinlog,errorLog) << "Empty file name" << STD_endl;
@@ -800,13 +801,13 @@ class FileIOTest : public UnitTest {
     // Testing whether files are sorted alphabetically according to their file name
     STD_string tmpdir(tempfile());
     if(createdir(tmpdir.c_str())) return false;
-    int testsize=16;
+    unsigned int testsize=16;
     Data<float,4> testslice(1,1,testsize,testsize);
 
     int nfiles=22;
     for(int i=0; i<nfiles; i++) {
       testslice=float(i);
-      if(testslice.autowrite(tmpdir+SEPARATOR_STR+itos(i,nfiles)+".jdx")<0) return false;
+      if(testslice.autowrite(tmpdir+SEPARATOR_STR+itos(i,nfiles)+".xml")<0) return false;
     }
 
     Data<float,4> testdirarr;
@@ -869,7 +870,7 @@ class FileIOTest : public UnitTest {
 
 void create_fileio_testarr(Data<float,4>& testarr, const TinyVector<int,4>& shape) {
   testarr.resize(shape); testarr=0.0;
-  for(int i=0; i<testarr.numElements(); i++) {
+  for(unsigned int i=0; i<testarr.numElements(); i++) {
     TinyVector<int,4> indexvec=testarr.create_index(i);
     for(int j=0; j<testarr.rank(); j++) {
       testarr(indexvec)+=pow(-1.0,i)*indexvec(j)*pow(10.0,j-2);
@@ -912,7 +913,7 @@ class FileIOFormatTest : public UnitTest {
     Data<CompareType,4> a1copy;
     a1.convert_to(a1copy);
 
-    for(int i=0; i<a1.numElements(); i++) {
+    for(unsigned int i=0; i<a1.numElements(); i++) {
       TinyVector<int,4> indexvec=a1.create_index(i);
       if(a1copy(indexvec)!=a2(indexvec)) {
         ODINLOG(odinlog,errorLog) << test << " failed, value mismatch at index " << indexvec << STD_endl;
@@ -1013,7 +1014,7 @@ class FileIOFormatTest : public UnitTest {
         Protocol protcopy(prot); // Create copy of protocol to use limited accuracy comparison of Protocol
         protcopy.geometry=readprot.geometry; // only geometry may differ
         if(!(prot==protcopy)) { // use limited accuracy comparison of Protocol
-          ODINLOG(odinlog,errorLog) << "autowrite/autoread(geo)" << (*it) << " failed: prot.geometry=" << prot.geometry << "protcopy.geometry=" << protcopy.geometry << STD_endl;
+          ODINLOG(odinlog,errorLog) << "autowrite/autoread(geo)" << (*it) << " failed: prot.geometry=" << prot.geometry << "readprot.geometry=" << protcopy.geometry << STD_endl;
           return false;
         }
       }
@@ -1032,7 +1033,10 @@ void alloc_FileIOTest() { // create test instances
 
   new FileIOTest;
 
-  new FileIOFormatTest<7, 13, double, false,true,false,true,true>("jdx");
+
+#ifdef VTKSUPPORT
+  new FileIOFormatTest<7, 13, u8bit, false,false,false,false,false>("vtk");
+#endif
 
 #ifdef PNGSUPPORT
   new FileIOFormatTest<7, 13, u8bit, true,false,false,false,false>("png");
@@ -1041,6 +1045,7 @@ void alloc_FileIOTest() { // create test instances
 #ifdef HAVE_LIBZ
 #ifndef STREAM_REPLACEMENT
   new FileIOFormatTest<7, 13, double, false,true,false,true,true>("jdx.gz");
+  new FileIOFormatTest<7, 13, float, false,true,false,true,true>("xml.gz");
 #endif
 #endif
 
@@ -1057,6 +1062,10 @@ void alloc_FileIOTest() { // create test instances
 #endif
 #endif
 
+#ifdef ISMRMRDSUPPORT
+  new FileIOFormatTest<7, 13, float, false,true,false,true,false>("h5");
+#endif
+
   new FileIOFormatTest<7, 13, s16bit, false,false,false,false,false>("hdr", "interfile","s16bit");
   new FileIOFormatTest<7, 13, s16bit, false,false,false,false,false>("hdr", "interfile","float");
 
