@@ -57,7 +57,7 @@ bool FilterAutoMask::process(Data<float,4>& data, Protocol& prot) const {
   Data<float,1> hist(nslots); hist=0.0;
 
   // create histogram
-  for(int i=0; i<data.size(); i++) {
+  for(unsigned int i=0; i<data.size(); i++) {
     float val=data(data.create_index(i));
     int slot=int(secureDivision(val,step));
     ODINLOG(odinlog,normalDebug) << "val/slot=" << val << "/" << slot << STD_endl; 
@@ -163,7 +163,7 @@ bool FilterUseMask::process(Data<float,4>& data, Protocol& prot) const {
   }
 
   fvector vals;
-  for(int i=0; i<data.size(); i++) {
+  for(unsigned int i=0; i<data.size(); i++) {
     TinyVector<int,4> index=data.create_index(i);
     float val=data(index);
     index(timeDim)=0;
