@@ -2,7 +2,7 @@
                           filter_mask.h  -  description
                              -------------------
     begin                : Wed Nov 5 2008
-    copyright            : (C) 2000-2014 by Thies Jochimsen
+    copyright            : (C) 2000-2015 by Thies Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -22,8 +22,8 @@
 
 class FilterGenMask : public FilterStep {
 
-  JDXfloat min;
-  JDXfloat max;
+  LDRfloat min;
+  LDRfloat max;
 
 
   STD_string label() const {return "genmask";}
@@ -38,7 +38,7 @@ class FilterGenMask : public FilterStep {
 
 class FilterAutoMask : public FilterStep {
 
-//  JDXfileName dump_histogram_fname;
+//  LDRfileName dump_histogram_fname;
 
   STD_string label() const {return "automask";}
   STD_string description() const {return "Create mask using automatic histogram-based threshold";}
@@ -52,7 +52,7 @@ class FilterAutoMask : public FilterStep {
 
 class FilterQuantilMask : public FilterStep {
 
-  JDXfloat fraction;
+  LDRfloat fraction;
 
   STD_string label() const {return "quantilmask";}
   STD_string description() const {return "Create mask including all voxels above the given fractional threshold";}
@@ -66,7 +66,7 @@ class FilterQuantilMask : public FilterStep {
 
 class FilterUseMask : public FilterStep {
 
-  JDXfileName fname;
+  LDRfileName fname;
 
   STD_string label() const {return "usemask";}
   STD_string description() const {return "Create 1D dataset including all values within mask from file";}
