@@ -2,7 +2,7 @@
                           fitting.h  -  description
                              -------------------
     begin                : Fri Apr 6 2001
-    copyright            : (C) 2000-2014 by Thies Jochimsen & Michael von Mengershausen
+    copyright            : (C) 2000-2015 by Thies Jochimsen & Michael von Mengershausen
     email                : thies@jochimsen.de  mengers@cns.mpg.de
  ***************************************************************************/
 
@@ -358,11 +358,11 @@ bool PolynomialFunction<N_rank>::fit(const Array<float,1>& yvals, const Array<fl
   int npts=yvals.size();
 
   Array<float,1> sigma(npts);
-  if(ysigma.size()==npts) sigma=ysigma;
+  if(int(ysigma.size())==npts) sigma=ysigma;
   else sigma=1.0;
 
   Array<float,1> x(npts);
-  if(xvals.size()==npts) x=xvals;
+  if(int(xvals.size())==npts) x=xvals;
   else for(int ipt=0; ipt<npts; ipt++) x(ipt)=ipt;
 
 
