@@ -49,13 +49,13 @@ STD_string Step<T>::args_description() const {
 
 
 template <class T>
-void Step<T>::append_opts(JcampDxBlock& parblock) {
+void Step<T>::append_opts(LDRblock& parblock) {
   parblock.merge(args);
 }
 
 
 template <class T>
-void Step<T>::append_arg(JcampDxClass& arg, const STD_string& arglabel) {
+void Step<T>::append_arg(LDRbase& arg, const STD_string& arglabel) {
   arg.set_label(label()+"_"+arglabel);
   args.append(arg);
 }
@@ -66,7 +66,7 @@ void Step<T>::append_arg(JcampDxClass& arg, const STD_string& arglabel) {
 
 
 template <class T>
-StepFactory<T>::StepFactory(JcampDxBlock* parblock) {
+StepFactory<T>::StepFactory(LDRblock* parblock) {
   STD_list<T*> steplist;
   T::create_templates(steplist);
 
@@ -131,7 +131,7 @@ STD_string StepFactory<T>::manual() const {
     doc.description=it->second->description();
     T::interface_description(it->second, doc.in, doc.out);
 
-    JcampDxBlock parblock;
+    LDRblock parblock;
     it->second->append_opts(parblock);
     int nargs=parblock.numof_pars();
     for(int i=0; i<nargs; i++) {
