@@ -6,19 +6,19 @@
 ///////////////////////////////////////////////////////////////////////
 
 
-const kspace_coord& JDXtrajectory::calculate(float s) const {
-  JDXfunctionPlugIn::coord_retval=kspace_coord();
+const kspace_coord& LDRtrajectory::calculate(float s) const {
+  LDRfunctionPlugIn::coord_retval=kspace_coord();
   if(allocated_function) return allocated_function->calculate_traj(s);
-  else return JDXfunctionPlugIn::coord_retval;
+  else return LDRfunctionPlugIn::coord_retval;
 }
 
 
 
 
-const traj_info& JDXtrajectory::get_traj_info() const {
-  JDXfunctionPlugIn::traj_info_retval=traj_info();
+const traj_info& LDRtrajectory::get_traj_info() const {
+  LDRfunctionPlugIn::traj_info_retval=traj_info();
   if(allocated_function) return allocated_function->get_traj_properties();
-  else return JDXfunctionPlugIn::traj_info_retval;
+  else return LDRfunctionPlugIn::traj_info_retval;
 }
 
 
@@ -26,20 +26,20 @@ const traj_info& JDXtrajectory::get_traj_info() const {
 ///////////////////////////////////////////////////////////////////////
 
 
-STD_complex JDXshape::calculate(const kspace_coord& coord ) const {
+STD_complex LDRshape::calculate(const kspace_coord& coord ) const {
   if(allocated_function) return allocated_function->calculate_shape(coord);
   return STD_complex(0.0);
 }
 
-STD_complex JDXshape::calculate(float s, float Tp) const {
+STD_complex LDRshape::calculate(float s, float Tp) const {
   if(allocated_function) return allocated_function->calculate_shape(s,Tp);
   return STD_complex(0.0);
 }
 
-const shape_info& JDXshape::get_shape_info() const {
-  JDXfunctionPlugIn::shape_info_retval=shape_info();
+const shape_info& LDRshape::get_shape_info() const {
+  LDRfunctionPlugIn::shape_info_retval=shape_info();
   if(allocated_function) return allocated_function->get_shape_properties();
-  else return JDXfunctionPlugIn::shape_info_retval;
+  else return LDRfunctionPlugIn::shape_info_retval;
 }
 
 
@@ -50,41 +50,41 @@ struct OdinPulseData {
 
   bool intactive;
 
-  JDXenum dim_mode;
-  JDXenum nucleus;
+  LDRenum dim_mode;
+  LDRenum nucleus;
 
-  JDXshape      shape;
-  JDXtrajectory trajectory;
-  JDXfilter     filter;
+  LDRshape      shape;
+  LDRtrajectory trajectory;
+  LDRfilter     filter;
 
-  JDXint npts;
-  JDXdouble Tp;
+  LDRint npts;
+  LDRdouble Tp;
 
-  JDXcomplexArr B1;
-  JDXfloatArr Gr;
-  JDXfloatArr Gp;
-  JDXfloatArr Gs;
+  LDRcomplexArr B1;
+  LDRfloatArr Gr;
+  LDRfloatArr Gp;
+  LDRfloatArr Gs;
 
-  JDXdouble B10;
-  JDXdouble G0;
+  LDRdouble B10;
+  LDRdouble G0;
 
-  JDXbool consider_system_cond_flag;
-  JDXbool consider_Nyquist_cond_flag;
-  JDXbool take_min_smoothing_kernel;
-  JDXdouble smoothing_kernel_size;
-  JDXtriple spatial_offset;
-  JDXdouble field_of_excitation;
+  LDRbool consider_system_cond_flag;
+  LDRbool consider_Nyquist_cond_flag;
+  LDRbool take_min_smoothing_kernel;
+  LDRdouble smoothing_kernel_size;
+  LDRtriple spatial_offset;
+  LDRdouble field_of_excitation;
 
-  JDXenum pulse_type;
+  LDRenum pulse_type;
 
-  JDXformula composite_pulse;
-  JDXint    npts_1pulse;
-  JDXdouble Tp_1pulse;
+  LDRformula composite_pulse;
+  LDRint    npts_1pulse;
+  LDRdouble Tp_1pulse;
 
-  JDXdouble pulse_gain;
-  JDXdouble pulse_power;
+  LDRdouble pulse_gain;
+  LDRdouble pulse_power;
 
-  JDXdouble flipangle;
+  LDRdouble flipangle;
   float flip_corr;
 
   funcMode old_mode;
@@ -139,7 +139,7 @@ float OdinPulse::max_kspace_step2 (const fvector& Gx, const fvector& Gy, float g
 //////////////////////////////////////////////////////////////////////////////////////////
 
 
-OdinPulse::OdinPulse(const STD_string& pulse_label,bool interactive) : JcampDxBlock(pulse_label), data(new OdinPulseData) {
+OdinPulse::OdinPulse(const STD_string& pulse_label,bool interactive) : LDRblock(pulse_label), data(new OdinPulseData) {
   set_label(pulse_label); // because SeqClass is a virtual base class
   Log<Seq> odinlog(this,"OdinPulse(...)");
 
@@ -290,7 +290,7 @@ int OdinPulse::append_all_members() {
 OdinPulse& OdinPulse::operator = (const OdinPulse& pulse) {
   Log<Seq> odinlog(this,"operator = (...)");
   SeqClass::operator = (pulse);
-  JcampDxBlock::operator = (pulse);
+  LDRblock::operator = (pulse);
   ODINLOG(odinlog,normalDebug) << "operator of base classes called" << STD_endl;
   (*data)=(*(pulse.data));
   OdinPulse::append_all_members();
@@ -480,12 +480,12 @@ double OdinPulse::get_flipangle() const {return data->flipangle;}
 
 
 
-int OdinPulse::load(const STD_string& filename) {
+int OdinPulse::load(const STD_string& filename, const LDRserBase& serializer) {
   Log<Seq> odinlog(this,"load");
 
 
   // determine the dim mode first and set the functions accordingly
-  data->dim_mode.load(filename);
+  data->dim_mode.load(filename,serializer);
   ODINLOG(odinlog,normalDebug) << "dim_mode/old_mode=" << int(data->dim_mode) << "/" << int(data->old_mode) << STD_endl;
 
   // switch before loading so that plugin parameters can be assigned properly
@@ -493,14 +493,13 @@ int OdinPulse::load(const STD_string& filename) {
   data->trajectory.set_function_mode(funcMode(int(data->dim_mode)));
 
   // then load the whole set of parameters and update the pulse
-  int result=JcampDxBlock::load(filename);
+  int result=LDRblock::load(filename,serializer);
 
   update();
 
   return result;
 }
 
-int OdinPulse::write(const STD_string& filename) const {return JcampDxBlock::write(filename);}
 
 
 float OdinPulse::ensure_unit_range(float x) {
@@ -551,9 +550,9 @@ OdinPulse& OdinPulse::generate() {
   funcMode mode=funcMode(int(data->dim_mode));
 
   // Zero gradients before calculating the selectively
-  data->Gr=JDXfloat(0.0);
-  data->Gp=JDXfloat(0.0);
-  data->Gs=JDXfloat(0.0);
+  data->Gr=LDRfloat(0.0);
+  data->Gp=LDRfloat(0.0);
+  data->Gs=LDRfloat(0.0);
   data->G0=0.0;
 
   float g0=0.0; // The scaling factor for the time-strength-independent gradient shape
@@ -742,7 +741,9 @@ OdinPulse& OdinPulse::generate() {
   // final scaling
   float Bmax = amplitude(data->B1).maxvalue();
   ODINLOG(odinlog,normalDebug) << "Bmax=" << Bmax << STD_endl;
-  if (Bmax <= 0.0) ODINLOG(odinlog,warningLog) << "RF-amplitude array=0.0 !" << STD_endl;
+  if (Bmax <= 0.0) {
+    ODINLOG(odinlog,warningLog) << "RF-amplitude array=0.0 !" << STD_endl;
+  }
   for (i = 0; i<data->npts_1pulse; i++) data->B1[i]*= secureInv(Bmax);
   ODINLOG(odinlog,normalDebug) << "final scaling done" << STD_endl;
 
@@ -1052,7 +1053,9 @@ void OdinPulse::simulate_pulse(SeqSimAbstract& sim, const Sample& sample) const
 int OdinPulse::write_rf_waveform (const STD_string& filename) const {
   Log<Seq> odinlog(this,"write_rf_waveform");
   int result=SeqPlatformProxy()->write_rf_waveform(filename,data->B1);
-  if(result<0) ODINLOG(odinlog,errorLog) << " failed" << STD_endl;
+  if(result<0) {
+    ODINLOG(odinlog,errorLog) << " failed" << STD_endl;
+  }
   return result;
 }
 
@@ -1067,6 +1070,8 @@ int OdinPulse::load_rf_waveform (const STD_string& filename) {
     data->B1=B1load;
   }
   if(n>=0) n=0;
-  if(n<0) ODINLOG(odinlog,errorLog) << " failed" << STD_endl;
+  if(n<0) {
+    ODINLOG(odinlog,errorLog) << " failed" << STD_endl;
+  }
   return n;
 }
