@@ -92,7 +92,7 @@ float SeqGradSpiral::evaluate(const fvector& spirpar) const {
 
 
 
-SeqGradSpiral::SeqGradSpiral(const STD_string& object_label, JDXtrajectory& traj, double dt, float resolution, unsigned int sizeRadial, unsigned int numofSegments, bool inwards, bool optimize, const STD_string& nucleus)
+SeqGradSpiral::SeqGradSpiral(const STD_string& object_label, LDRtrajectory& traj, double dt, float resolution, unsigned int sizeRadial, unsigned int numofSegments, bool inwards, bool optimize, const STD_string& nucleus)
     : SeqGradChanParallel(object_label), predelay(0.0),
       dt_cache(dt), resolution_cache(resolution), sizeRadial_cache(sizeRadial), gamma_cache(systemInfo->get_gamma(nucleus)) {
   Log<Seq> odinlog(this,"SeqGradSpiral(...)");
