@@ -2,7 +2,7 @@
                           seqsim.h  -  description
                              -------------------
     begin                : Tue Jun 11 2002
-    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    copyright            : (C) 2000-2015 by Thies H. Jochimsen
     email                : thies@jochimsen.de
  ***************************************************************************/
 
@@ -110,7 +110,7 @@ class SeqSimAbstract : public virtual SeqClass {
   * - Iterative simulation by simulate() using a structure with piece-wise constant fields.
   * - Finish simulation by calling finalize_simulation().
   */
-class SeqSimMagsi : public JcampDxBlock, public ThreadedLoop<SeqSimInterval,cvector,int>, public virtual SeqSimAbstract {
+class SeqSimMagsi : public LDRblock, public ThreadedLoop<SeqSimInterval,cvector,int>, public virtual SeqSimAbstract {
 
 
  public:
@@ -241,15 +241,15 @@ class SeqSimMagsi : public JcampDxBlock, public ThreadedLoop<SeqSimInterval,cvec
 
   void set_axes_cache(const Sample& sample);
 
-  JDXfloatArr Mx;
-  JDXfloatArr My;
-  JDXfloatArr Mz;
-  JDXfloatArr Mamp;
-  JDXfloatArr Mpha;
+  LDRfloatArr Mx;
+  LDRfloatArr My;
+  LDRfloatArr Mz;
+  LDRfloatArr Mamp;
+  LDRfloatArr Mpha;
 
-  JDXbool   online;
-  JDXaction update_now;
-  JDXtriple initial_vector;
+  LDRbool   online;
+  LDRaction update_now;
+  LDRtriple initial_vector;
 
 
   bool iactive;
